@@ -127,13 +127,10 @@ BEGIN_EVENT_TABLE(CMainFrame, wxNavigationEnabled<wxFrame>)
 	EVT_SIZE(CMainFrame::OnSize)
 	EVT_MENU(wxID_ANY, CMainFrame::OnMenuHandler)
 	EVT_TOOL(XRCID("ID_TOOLBAR_DISCONNECT"), CMainFrame::OnDisconnect)
-	EVT_MENU(XRCID("ID_MENU_SERVER_DISCONNECT"), CMainFrame::OnDisconnect)
 	EVT_TOOL(XRCID("ID_TOOLBAR_CANCEL"), CMainFrame::OnCancel)
-	EVT_MENU(XRCID("ID_CANCEL"), CMainFrame::OnCancel)
 	EVT_TOOL(XRCID("ID_TOOLBAR_RECONNECT"), CMainFrame::OnReconnect)
 	EVT_TOOL(XRCID("ID_MENU_SERVER_RECONNECT"), CMainFrame::OnReconnect)
 	EVT_TOOL(XRCID("ID_TOOLBAR_REFRESH"), CMainFrame::OnRefresh)
-	EVT_MENU(XRCID("ID_REFRESH"), CMainFrame::OnRefresh)
 	EVT_TOOL(XRCID("ID_TOOLBAR_SITEMANAGER"), CMainFrame::OnSiteManager)
 	EVT_CLOSE(CMainFrame::OnClose)
 #ifdef WITH_LIBDBUS
@@ -145,34 +142,20 @@ BEGIN_EVENT_TABLE(CMainFrame, wxNavigationEnabled<wxFrame>)
 	EVT_TOOL(XRCID("ID_TOOLBAR_LOCALTREEVIEW"), CMainFrame::OnToggleDirectoryTreeView)
 	EVT_TOOL(XRCID("ID_TOOLBAR_REMOTETREEVIEW"), CMainFrame::OnToggleDirectoryTreeView)
 	EVT_TOOL(XRCID("ID_TOOLBAR_QUEUEVIEW"), CMainFrame::OnToggleQueueView)
-	EVT_MENU(XRCID("ID_VIEW_TOOLBAR"), CMainFrame::OnToggleToolBar)
-	EVT_MENU(XRCID("ID_VIEW_MESSAGELOG"), CMainFrame::OnToggleLogView)
-	EVT_MENU(XRCID("ID_VIEW_LOCALTREE"), CMainFrame::OnToggleDirectoryTreeView)
-	EVT_MENU(XRCID("ID_VIEW_REMOTETREE"), CMainFrame::OnToggleDirectoryTreeView)
-	EVT_MENU(XRCID("ID_VIEW_QUEUE"), CMainFrame::OnToggleQueueView)
-	EVT_MENU(wxID_ABOUT, CMainFrame::OnMenuHelpAbout)
 	EVT_TOOL(XRCID("ID_TOOLBAR_FILTER"), CMainFrame::OnFilter)
 	EVT_TOOL_RCLICKED(XRCID("ID_TOOLBAR_FILTER"), CMainFrame::OnFilterRightclicked)
-#if FZ_MANUALUPDATECHECK
-	EVT_MENU(XRCID("ID_CHECKFORUPDATES"), CMainFrame::OnCheckForUpdates)
-	EVT_MENU(GetAvailableUpdateMenuId(), CMainFrame::OnCheckForUpdates)
-#endif //FZ_MANUALUPDATECHECK
 	EVT_TOOL_RCLICKED(XRCID("ID_TOOLBAR_SITEMANAGER"), CMainFrame::OnSitemanagerDropdown)
 #ifdef EVT_TOOL_DROPDOWN
 	EVT_TOOL_DROPDOWN(XRCID("ID_TOOLBAR_SITEMANAGER"), CMainFrame::OnSitemanagerDropdown)
 #endif
 	EVT_NAVIGATION_KEY(CMainFrame::OnNavigationKeyEvent)
 	EVT_CHAR_HOOK(CMainFrame::OnChar)
-	EVT_MENU(XRCID("ID_MENU_VIEW_FILTERS"), CMainFrame::OnFilter)
 	EVT_ACTIVATE(CMainFrame::OnActivate)
 	EVT_TOOL(XRCID("ID_TOOLBAR_COMPARISON"), CMainFrame::OnToolbarComparison)
 	EVT_TOOL_RCLICKED(XRCID("ID_TOOLBAR_COMPARISON"), CMainFrame::OnToolbarComparisonDropdown)
 #ifdef EVT_TOOL_DROPDOWN
 	EVT_TOOL_DROPDOWN(XRCID("ID_TOOLBAR_COMPARISON"), CMainFrame::OnToolbarComparisonDropdown)
 #endif
-	EVT_MENU(XRCID("ID_COMPARE_SIZE"), CMainFrame::OnDropdownComparisonMode)
-	EVT_MENU(XRCID("ID_COMPARE_DATE"), CMainFrame::OnDropdownComparisonMode)
-	EVT_MENU(XRCID("ID_COMPARE_HIDEIDENTICAL"), CMainFrame::OnDropdownComparisonHide)
 	EVT_TOOL(XRCID("ID_TOOLBAR_SYNCHRONIZED_BROWSING"), CMainFrame::OnSyncBrowse)
 #ifdef __WXMAC__
 	EVT_CHILD_FOCUS(CMainFrame::OnChildFocused)
@@ -183,9 +166,6 @@ BEGIN_EVENT_TABLE(CMainFrame, wxNavigationEnabled<wxFrame>)
 	EVT_COMMAND(wxID_ANY, fzEVT_TASKBAR_CLICK_DELAYED, CMainFrame::OnTaskBarClick_Delayed)
 #endif
 	EVT_TOOL(XRCID("ID_TOOLBAR_FIND"), CMainFrame::OnSearch)
-	EVT_MENU(XRCID("ID_MENU_SERVER_SEARCH"), CMainFrame::OnSearch)
-	EVT_MENU(XRCID("ID_MENU_FILE_NEWTAB"), CMainFrame::OnMenuNewTab)
-	EVT_MENU(XRCID("ID_MENU_FILE_CLOSETAB"), CMainFrame::OnMenuCloseTab)
 END_EVENT_TABLE()
 
 class CMainFrameStateEventHandler final : public CGlobalStateEventHandler
@@ -515,6 +495,10 @@ CMainFrame::CMainFrame(COptions& options)
 		m_pBottomSplitter->Initialize(m_pContextControl);
 	}
 
+#ifdef __WXMAC__
+	EnableFullScreenView(true, wxFULLSCREEN_NOMENUBAR);
+#endif
+
 	wxGetApp().AddStartupProfileRecord("CMainFrame::CMainFrame pre layout");
 	m_pWindowStateManager = new CWindowStateManager(this);
 	m_pWindowStateManager->Restore(OPTION_MAINWINDOW_POSITION);
@@ -646,13 +630,74 @@ void CMainFrame::CreateQuickconnectBar()
 
 void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 {
-	if (event.GetId() == XRCID("wxID_EXIT")) {
+	if (!wxDialogEx::IsActiveTLW(this)) {
+		return;
+	}
+
+	auto const id = event.GetId();
+	if (id == XRCID("ID_MENU_SERVER_SEARCH")) {
+		OnSearch(event);
+	}
+	else if (id == XRCID("ID_MENU_FILE_NEWTAB")) {
+		OnMenuNewTab(event);
+	}
+	else if (id == XRCID("ID_MENU_FILE_CLOSETAB")) {
+		OnMenuCloseTab(event);
+	}
+	else if (id == XRCID("ID_MENU_SERVER_DISCONNECT")) {
+		OnDisconnect(event);
+	}
+	else if (id == XRCID("ID_CANCEL")) {
+		OnCancel(event);
+	}
+	else if (id == XRCID("ID_REFRESH")) {
+		OnRefresh(event);
+	}
+	else if (id == XRCID("ID_VIEW_TOOLBAR")) {
+		OnToggleToolBar(event);
+	}
+	else if (id == XRCID("ID_VIEW_MESSAGELOG")) {
+		OnToggleLogView(event);
+	}
+	else if (id == XRCID("ID_VIEW_LOCALTREE")) {
+		OnToggleDirectoryTreeView(event);
+	}
+	else if (id == XRCID("ID_VIEW_REMOTETREE")) {
+		OnToggleDirectoryTreeView(event);
+	}
+	else if (id == XRCID("ID_VIEW_QUEUE")) {
+		OnToggleQueueView(event);
+	}
+	else if (id == wxID_ABOUT) {
+		OnMenuHelpAbout(event);
+	}
+#if FZ_MANUALUPDATECHECK
+	else if (id == XRCID("ID_CHECKFORUPDATES")) {
+		OnCheckForUpdates(event);
+	}
+	else if (id == GetAvailableUpdateMenuId()) {
+		OnCheckForUpdates(event);
+	}
+#endif //FZ_MANUALUPDATECHECK
+	else if (id == XRCID("ID_MENU_VIEW_FILTERS")) {
+		OnFilter(event);
+	}
+	else if (id == XRCID("ID_COMPARE_SIZE")) {
+		OnDropdownComparisonMode(event);
+	}
+	else if (id == XRCID("ID_COMPARE_DATE")) {
+		OnDropdownComparisonMode(event);
+	}
+	else if (id == XRCID("ID_COMPARE_HIDEIDENTICAL")) {
+		OnDropdownComparisonHide(event);
+	}
+	else if (id == XRCID("wxID_EXIT")) {
 		Close();
 	}
-	else if (event.GetId() == XRCID("ID_MENU_FILE_SITEMANAGER")) {
+	else if (id == XRCID("ID_MENU_FILE_SITEMANAGER")) {
 		OpenSiteManager();
 	}
-	else if (event.GetId() == XRCID("ID_MENU_FILE_COPYSITEMANAGER")) {
+	else if (id == XRCID("ID_MENU_FILE_COPYSITEMANAGER")) {
 		Site site;
 		CState* pState = CContextManager::Get()->GetCurrentContext();
 		if (pState) {
@@ -664,7 +709,7 @@ void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 		}
 		OpenSiteManager(&site);
 	}
-	else if (event.GetId() == XRCID("ID_MENU_SERVER_CMD")) {
+	else if (id == XRCID("ID_MENU_SERVER_CMD")) {
 		CState* pState = CContextManager::Get()->GetCurrentContext();
 		if (!pState || !pState->m_pCommandQueue || !pState->IsRemoteConnected() || !pState->IsRemoteIdle()) {
 			return;
@@ -703,16 +748,16 @@ void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 		}
 		pState->m_pCommandQueue->ProcessCommand(new CRawCommand(dlg.GetValue().ToStdWstring()));
 	}
-	else if (event.GetId() == XRCID("wxID_PREFERENCES")) {
+	else if (id == XRCID("wxID_PREFERENCES")) {
 		OnMenuEditSettings(event);
 	}
-	else if (event.GetId() == XRCID("ID_MENU_EDIT_NETCONFWIZARD")) {
+	else if (id == XRCID("ID_MENU_EDIT_NETCONFWIZARD")) {
 		CNetConfWizard wizard(this, &options_, m_engineContext);
 		wizard.Load();
 		wizard.Run();
 	}
 	// Debug menu
-	else if (event.GetId() == XRCID("ID_CIPHERS")) {
+	else if (id == XRCID("ID_CIPHERS")) {
 		CInputDialog dlg;
 		dlg.Create(this, _T("Ciphers"), _T("Priority string:"));
 		dlg.AllowEmpty(true);
@@ -721,21 +766,21 @@ void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 			wxMessageBoxEx(fz::to_wstring(ciphers), _T("Ciphers"));
 		}
 	}
-	else if (event.GetId() == XRCID("ID_CLEARCACHE_LAYOUT")) {
+	else if (id == XRCID("ID_CLEARCACHE_LAYOUT")) {
 		CWrapEngine::ClearCache();
 	}
-	else if (event.GetId() == XRCID("ID_CLEAR_UPDATER")) {
+	else if (id == XRCID("ID_CLEAR_UPDATER")) {
 #if FZ_MANUALUPDATECHECK
 		if (m_pUpdater) {
 			m_pUpdater->Reset();
 		}
 #endif
 	}
-	else if (event.GetId() == XRCID("ID_MENU_TRANSFER_FILEEXISTS")) {
+	else if (id == XRCID("ID_MENU_TRANSFER_FILEEXISTS")) {
 		CDefaultFileExistsDlg dlg;
 		dlg.Run(this, false);
 	}
-	else if (event.GetId() == XRCID("ID_MENU_EDIT_CLEARPRIVATEDATA")) {
+	else if (id == XRCID("ID_MENU_EDIT_CLEARPRIVATEDATA")) {
 		CClearPrivateDataDialog* pDlg = CClearPrivateDataDialog::Create(this);
 		if (!pDlg) {
 			return;
@@ -751,7 +796,7 @@ void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 			m_pToolBar->UpdateToolbarState();
 		}
 	}
-	else if (event.GetId() == XRCID("ID_MENU_SERVER_VIEWHIDDEN")) {
+	else if (id == XRCID("ID_MENU_SERVER_VIEWHIDDEN")) {
 		bool showHidden = options_.get_int(OPTION_VIEW_HIDDEN_FILES) ? 0 : 1;
 		if (showHidden) {
 			CConditionalDialog dlg(this, CConditionalDialog::viewhidden, CConditionalDialog::ok, false);
@@ -773,28 +818,28 @@ void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 			}
 		}
 	}
-	else if (event.GetId() == XRCID("ID_EXPORT")) {
+	else if (id == XRCID("ID_EXPORT")) {
 		CExportDialog dlg(this, m_pQueueView);
 		dlg.Run();
 	}
-	else if (event.GetId() == XRCID("ID_IMPORT")) {
+	else if (id == XRCID("ID_IMPORT")) {
 		CImportDialog dlg(this, m_pQueueView);
 		dlg.Run();
 	}
-	else if (event.GetId() == XRCID("ID_MENU_FILE_EDITED")) {
+	else if (id == XRCID("ID_MENU_FILE_EDITED")) {
 		CEditHandlerStatusDialog dlg(this);
 		dlg.ShowModal();
 	}
-	else if (event.GetId() == XRCID("ID_MENU_TRANSFER_TYPE_AUTO")) {
+	else if (id == XRCID("ID_MENU_TRANSFER_TYPE_AUTO")) {
 		options_.set(OPTION_ASCIIBINARY, 0);
 	}
-	else if (event.GetId() == XRCID("ID_MENU_TRANSFER_TYPE_ASCII")) {
+	else if (id == XRCID("ID_MENU_TRANSFER_TYPE_ASCII")) {
 		options_.set(OPTION_ASCIIBINARY, 1);
 	}
-	else if (event.GetId() == XRCID("ID_MENU_TRANSFER_TYPE_BINARY")) {
+	else if (id == XRCID("ID_MENU_TRANSFER_TYPE_BINARY")) {
 		options_.set(OPTION_ASCIIBINARY, 2);
 	}
-	else if (event.GetId() == XRCID("ID_MENU_TRANSFER_PRESERVETIMES")) {
+	else if (id == XRCID("ID_MENU_TRANSFER_PRESERVETIMES")) {
 		if (event.IsChecked()) {
 			CConditionalDialog dlg(this, CConditionalDialog::confirm_preserve_timestamps, CConditionalDialog::ok, true);
 			dlg.SetTitle(_("Preserving file timestamps"));
@@ -803,16 +848,16 @@ void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 		}
 		options_.set(OPTION_PRESERVE_TIMESTAMPS, event.IsChecked() ? 1 : 0);
 	}
-	else if (event.GetId() == XRCID("ID_MENU_TRANSFER_PROCESSQUEUE")) {
+	else if (id == XRCID("ID_MENU_TRANSFER_PROCESSQUEUE")) {
 		if (m_pQueueView) {
 			m_pQueueView->SetActive(event.IsChecked());
 		}
 	}
-	else if (event.GetId() == XRCID("ID_MENU_HELP_GETTINGHELP") ||
-			 event.GetId() == XRCID("ID_MENU_HELP_BUGREPORT"))
+	else if (id == XRCID("ID_MENU_HELP_GETTINGHELP") ||
+			 id == XRCID("ID_MENU_HELP_BUGREPORT"))
 	{
 		wxString url(_T("https://filezilla-project.org/support.php?type=client&mode="));
-		if (event.GetId() == XRCID("ID_MENU_HELP_GETTINGHELP")) {
+		if (id == XRCID("ID_MENU_HELP_GETTINGHELP")) {
 			url += _T("help");
 		}
 		else {
@@ -840,12 +885,12 @@ void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 		}
 		wxLaunchDefaultBrowser(url);
 	}
-	else if (event.GetId() == XRCID("ID_MENU_VIEW_FILELISTSTATUSBAR")) {
+	else if (id == XRCID("ID_MENU_VIEW_FILELISTSTATUSBAR")) {
 		bool show = options_.get_int(OPTION_FILELIST_STATUSBAR) == 0;
 		options_.set(OPTION_FILELIST_STATUSBAR, show ? 1 : 0);
 		CContextControl::_context_controls* controls = m_pContextControl ? m_pContextControl->GetCurrentControls() : 0;
 		if (controls && controls->pLocalListViewPanel) {
-			wxStatusBar* pStatusBar = controls->pLocalListViewPanel->GetStatusBar();
+			auto* pStatusBar = controls->pLocalListViewPanel->GetStatusBar();
 			if (pStatusBar) {
 				pStatusBar->Show(show);
 				wxSizeEvent evt;
@@ -853,7 +898,7 @@ void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 			}
 		}
 		if (controls && controls->pRemoteListViewPanel) {
-			wxStatusBar* pStatusBar = controls->pRemoteListViewPanel->GetStatusBar();
+			auto* pStatusBar = controls->pRemoteListViewPanel->GetStatusBar();
 			if (pStatusBar) {
 				pStatusBar->Show(show);
 				wxSizeEvent evt;
@@ -861,7 +906,7 @@ void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 			}
 		}
 	}
-	else if (event.GetId() == XRCID("ID_VIEW_QUICKCONNECT")) {
+	else if (id == XRCID("ID_VIEW_QUICKCONNECT")) {
 		if (!m_pQuickconnectBar) {
 			CreateQuickconnectBar();
 		}
@@ -873,7 +918,7 @@ void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 		}
 		options_.set(OPTION_SHOW_QUICKCONNECT, m_pQuickconnectBar != 0);
 	}
-	else if (event.GetId() == XRCID("ID_MENU_TRANSFER_MANUAL")) {
+	else if (id == XRCID("ID_MENU_TRANSFER_MANUAL")) {
 		CState* pState = CContextManager::Get()->GetCurrentContext();
 		if (!pState || !m_pQueueView) {
 			wxBell();
@@ -882,7 +927,7 @@ void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 		CManualTransfer dlg(options_, m_pQueueView);
 		dlg.Run(this, pState);
 	}
-	else if (event.GetId() == XRCID("ID_BOOKMARK_ADD") || event.GetId() == XRCID("ID_BOOKMARK_MANAGE")) {
+	else if (id == XRCID("ID_BOOKMARK_ADD") || id == XRCID("ID_BOOKMARK_MANAGE")) {
 		CState* pState = CContextManager::Get()->GetCurrentContext();
 		if (!pState) {
 			return;
@@ -898,7 +943,7 @@ void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 
 		// controls->last_bookmark_path can get modified if it's empty now
 		int res;
-		if (event.GetId() == XRCID("ID_BOOKMARK_ADD")) {
+		if (id == XRCID("ID_BOOKMARK_ADD")) {
 			CNewBookmarkDialog dlg(this, sitePath, old_site ? &old_site : 0);
 			res = dlg.Run(pState->GetLocalDir().GetPath(), pState->GetRemotePath());
 		}
@@ -920,11 +965,11 @@ void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 			}
 		}
 	}
-	else if (event.GetId() == XRCID("ID_MENU_HELP_WELCOME")) {
+	else if (id == XRCID("ID_MENU_HELP_WELCOME")) {
 		CWelcomeDialog dlg(options_, this);
 		dlg.Run(true);
 	}
-	else if (event.GetId() == XRCID("ID_MENU_TRANSFER_SPEEDLIMITS_ENABLE")) {
+	else if (id == XRCID("ID_MENU_TRANSFER_SPEEDLIMITS_ENABLE")) {
 		bool enable = options_.get_int(OPTION_SPEEDLIMIT_ENABLE) == 0;
 
 		const int downloadLimit = options_.get_int(OPTION_SPEEDLIMIT_INBOUND);
@@ -937,11 +982,11 @@ void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 			options_.set(OPTION_SPEEDLIMIT_ENABLE, enable ? 1 : 0);
 		}
 	}
-	else if (event.GetId() == XRCID("ID_MENU_TRANSFER_SPEEDLIMITS_CONFIGURE")) {
+	else if (id == XRCID("ID_MENU_TRANSFER_SPEEDLIMITS_CONFIGURE")) {
 		CSpeedLimitsDialog dlg;
 		dlg.Run(this);
 	}
-	else if (event.GetId() == m_comparisonToggleAcceleratorId) {
+	else if (id == m_comparisonToggleAcceleratorId) {
 		CState* pState = CContextManager::Get()->GetCurrentContext();
 		if (!pState) {
 			return;
@@ -960,7 +1005,7 @@ void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 	}
 	else {
 		for (int i = 0; i < 10; ++i) {
-			if (event.GetId() != tab_hotkey_ids[i]) {
+			if (id != tab_hotkey_ids[i]) {
 				continue;
 			}
 
@@ -977,7 +1022,7 @@ void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 			return;
 		}
 
-		std::unique_ptr<Site> pData = CSiteManager::GetSiteById(event.GetId());
+		std::unique_ptr<Site> pData = CSiteManager::GetSiteById(id);
 
 		if (!pData) {
 			event.Skip();
@@ -1822,7 +1867,7 @@ void CMainFrame::TriggerUpdateDialog()
 		return;
 	}
 
-	if (!wxDialogEx::CanShowPopupDialog()) {
+	if (!wxDialogEx::CanShowPopupDialog(this)) {
 		update_dialog_timer_.Start(1000, true);
 		return;
 	}
@@ -2780,7 +2825,7 @@ void CMainFrame::PostInitialize()
 	bool startupReconnect = startupAction == 2;
 
 	if (startupAction == 1) {
-		if (wxDialogEx::CanShowPopupDialog()) {
+		if (wxDialogEx::CanShowPopupDialog(this)) {
 			OpenSiteManager();
 		}
 		startupReconnect = false;
@@ -2880,6 +2925,7 @@ void CMainFrame::SetupKeyboardAccelerators()
 #ifdef __WXMAC__
 	entries.emplace_back(wxACCEL_CMD, ',', XRCID("wxID_PREFERENCES"));
 
+#if !wxCHECK_VERSION(3, 2,1)
 	keyboardCommands[wxNewId()] = std::make_pair([](wxTextEntry* e) { e->Cut(); }, 'X');
 	keyboardCommands[wxNewId()] = std::make_pair([](wxTextEntry* e) { e->Copy(); }, 'C');
 	keyboardCommands[wxNewId()] = std::make_pair([](wxTextEntry* e) { e->Paste(); }, 'V');
@@ -2888,6 +2934,7 @@ void CMainFrame::SetupKeyboardAccelerators()
 	for (auto const& command : keyboardCommands) {
 		entries.emplace_back(wxACCEL_CMD, command.second.second, command.first);
 	}
+#endif
 
 	// Ctrl+(Shift+)Tab to switch between tabs
 	int id = wxNewId();
